@@ -6,6 +6,7 @@ import faulthandler
 import os
 import sys
 
+from suanpan.app.base import APP
 from suanpan.imports import imports
 
 
@@ -14,6 +15,11 @@ def run(component, *args, **kwargs):
         component = f"{component[:-3]}.app" if component.endswith(
             ".py") else component
         component = imports(component)
+        if not isinstance(component, APP):
+            try:
+                return component(*args, **kwargs)
+            except:
+                return component()
     return component.start(*args, **kwargs)
 
 
